@@ -1,4 +1,21 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2008,2009 Sebastian Pölsterl
+#
+# This file is part of GNOME DVB Daemon.
+#
+# GNOME DVB Daemon is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# GNOME DVB Daemon is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
+
 import gtk
 import pango
 import gobject
@@ -11,6 +28,7 @@ from gnomedvb.ui.widgets.ScheduleView import ScheduleView
 from gnomedvb.ui.timers.EditTimersDialog import EditTimersDialog
 from gnomedvb.ui.timers.TimerDialog import NoTimerCreatedDialog
 from gnomedvb.ui.preferences.Preferences import Preferences
+from gnomedvb.ui.recordings.RecordingsDialog import RecordingsDialog
 
 class HelpBox(gtk.EventBox):
 
@@ -120,6 +138,7 @@ class ControlCenterWindow(gtk.Window):
         <menubar name="MenuBar">
           <menu action="Timers">
             <menuitem action="EditTimers"/>
+            <menuitem action="Recordings"/>
             <separator/>
             <menuitem action="Quit"/>
           </menu>
@@ -127,6 +146,7 @@ class ControlCenterWindow(gtk.Window):
             <menuitem action="Preferences"/>
           </menu>
           <menu action="View">
+            <menuitem action="Refresh"/>
             <menuitem action="PrevDay"/>
             <menuitem action="NextDay"/>
             <separator/>
@@ -159,6 +179,8 @@ class ControlCenterWindow(gtk.Window):
         actiongroup.add_actions([
             ('EditTimers', None, _('_Manage'), None,
              _('Manage timers'), self._on_button_display_timers_clicked),
+            ('Recordings', None, _('_Recordings'), None,
+             _('Manage recordings'), self._on_button_recordings_clicked),
             ('Quit', gtk.STOCK_QUIT, _('_Quit'), None,
              _('Quit the Program'), gtk.main_quit)])
         uimanager.insert_action_group(actiongroup, 1)
@@ -172,6 +194,8 @@ class ControlCenterWindow(gtk.Window):
         
         actiongroup = gtk.ActionGroup('View')
         actiongroup.add_actions([
+            ('Refresh', gtk.STOCK_REFRESH, _('Refresh'), None,
+             _('Refresh program guide'), self._on_refresh_clicked),
             ('PrevDay', None, _('Previous Day'), '<Control>B',
              _('Go to previous day'), self._on_button_prev_day_clicked),
             ('NextDay', None, _('Next Day'), '<Control>N',
@@ -210,6 +234,16 @@ class ControlCenterWindow(gtk.Window):
         self.timersitem.set_image(timers_image)
         self.timersitem.set_sensitive(False)
         
+        pixbuf = icon_theme.load_icon("video", gtk.ICON_SIZE_MENU, gtk.ICON_LOOKUP_USE_BUILTIN)
+        recordings_image = gtk.image_new_from_pixbuf(pixbuf)
+        recordings_image.show()
+        
+        recordings = uimanager.get_widget('/MenuBar/Timers/Recordings')
+        recordings.set_image(recordings_image)
+        
+        self.refresh_menuitem = uimanager.get_widget('/MenuBar/View/Refresh')
+        self.refresh_menuitem.set_sensitive(False)
+        
         self.prev_day_menuitem = uimanager.get_widget('/MenuBar/View/PrevDay')
         prev_image = gtk.image_new_from_stock(gtk.STOCK_GO_BACK, gtk.ICON_SIZE_MENU)
         prev_image.show()
@@ -245,9 +279,24 @@ class ControlCenterWindow(gtk.Window):
         self.button_display_timers.show()
         self.toolbar.insert(self.button_display_timers, 0)
         
+        pixbuf = icon_theme.load_icon("video", gtk.ICON_SIZE_MENU, gtk.ICON_LOOKUP_USE_BUILTIN)
+        recordings_image = gtk.image_new_from_pixbuf(pixbuf)
+        recordings_image.show()
+        
+        button_recordings = gtk.ToolButton(icon_widget=recordings_image, label=_("Recordings"))
+        button_recordings.connect("clicked", self._on_button_recordings_clicked)
+        button_recordings.show()
+        self.toolbar.insert(button_recordings, 1)
+         
         sep = gtk.SeparatorToolItem()
         sep.show()
-        self.toolbar.insert(sep, 1)
+        self.toolbar.insert(sep, 2)
+        
+        self.refresh_button = gtk.ToolButton(gtk.STOCK_REFRESH)
+        self.refresh_button.connect("clicked", self._on_refresh_clicked)
+        self.refresh_button.set_tooltip_markup(_("Refresh program guide"))        
+        self.refresh_button.show()
+        self.toolbar.insert(self.refresh_button, 3)
         
         prev_image = gtk.image_new_from_stock(gtk.STOCK_GO_BACK, gtk.ICON_SIZE_LARGE_TOOLBAR)
         prev_image.show()
@@ -256,7 +305,7 @@ class ControlCenterWindow(gtk.Window):
         self.button_prev_day.set_tooltip_markup(_("Go to previous day"))
         self.button_prev_day.set_sensitive(False)
         self.button_prev_day.show()
-        self.toolbar.insert(self.button_prev_day, 2)
+        self.toolbar.insert(self.button_prev_day, 4)
         
         next_image = gtk.image_new_from_stock(gtk.STOCK_GO_FORWARD, gtk.ICON_SIZE_LARGE_TOOLBAR)
         next_image.show()
@@ -265,12 +314,12 @@ class ControlCenterWindow(gtk.Window):
         self.button_next_day.set_tooltip_markup(_("Go to next day"))
         self.button_next_day.set_sensitive(False)
         self.button_next_day.show()
-        self.toolbar.insert(self.button_next_day, 3)
-         
+        self.toolbar.insert(self.button_next_day, 5)
+        
     def get_device_groups(self):
         for group in self.manager.get_registered_device_groups():
             self._append_group(group)
-       
+    
     def _select_first_group(self):
         self.devgroupscombo.set_active(0)
         self.channelsview.grab_focus()
@@ -360,6 +409,7 @@ class ControlCenterWindow(gtk.Window):
                 self.hpaned.pack2(self.scrolledschedule)
                 self._set_previous_day_sensitive(True)
                 self._set_next_day_sensitive(True)
+                self._set_refresh_sensitive(True)
         else:
             # Display help message if it isn't already displayed
             if child != self.help_eventbox:
@@ -371,6 +421,7 @@ class ControlCenterWindow(gtk.Window):
         self.hpaned.pack2(self.help_eventbox)
         self._set_previous_day_sensitive(False)
         self._set_next_day_sensitive(False)
+        self._set_refresh_sensitive(False)
         
         if len(self.devgroupslist) == 0:
             self.help_eventbox.set_markup(self.create_group_text)
@@ -388,6 +439,10 @@ class ControlCenterWindow(gtk.Window):
     def _set_timers_sensitive(self, val):
         self.button_display_timers.set_sensitive(val)
         self.timersitem.set_sensitive(val)
+        
+    def _set_refresh_sensitive(self, val):
+       self.refresh_button.set_sensitive(val) 
+       self.refresh_menuitem.set_sensitive(val)
        
     def _on_event_selected(self, treeview, event):
         if event.type == gtk.gdk._2BUTTON_PRESS:
@@ -416,6 +471,9 @@ class ControlCenterWindow(gtk.Window):
             edit = EditTimersDialog(group_id, self)
             edit.run()
             edit.destroy()
+            
+    def _on_refresh_clicked(self, button):
+        self.schedulestore.reload_all()
    
     def _on_button_prev_day_clicked(self, button):
         if self.schedulestore != None:
@@ -454,6 +512,11 @@ class ControlCenterWindow(gtk.Window):
         prefs.run()
         prefs.destroy()
         
+    def _on_button_recordings_clicked(self, button):
+        dialog = RecordingsDialog(self)
+        dialog.run()
+        dialog.destroy()
+        
     def _on_view_channels_clicked(self, action):
         if self.vbox_left:
             if action.get_active():
