@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 2008,2009 Sebastian Pölsterl
+ *
+ * This file is part of GNOME DVB Daemon.
+ *
+ * GNOME DVB Daemon is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * GNOME DVB Daemon is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include <src/Main.h>
 #include <dbus/dbus-glib-lowlevel.h>
@@ -5,21 +23,17 @@
 #include <signal.h>
 #include <gst/gst.h>
 #include <stdio.h>
-#include <gee/list.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
+#include <gee.h>
 #include <gst/rtsp-server/rtsp-media-mapping.h>
 #include "src/Constants.h"
 #include "src/Factory.h"
 #include "src/TimersStore.h"
 #include "src/ConfigStore.h"
 #include "src/DeviceGroup.h"
-#include "src/EPGScanner.h"
 #include "src/Recorder.h"
 #include "src/Timer.h"
 #include "src/rtsp/MediaMapping.h"
 #include <dbus/dbus.h>
-#include <dbus/dbus-glib.h>
 
 typedef struct _DBusObjectVTable _DBusObjectVTable;
 
@@ -45,6 +59,7 @@ static void _main_on_exit_cutils_signal_signal_handler (gint signum);
 static void _main_log_func_glog_func (const char* log_domain, GLogLevelFlags log_levels, const char* message, gpointer self);
 static void main_instance_init (Main * self);
 static void _vala_dbus_register_object (DBusConnection* connection, const char* path, void* object);
+static void _vala_dbus_unregister_object (gpointer connection, GObject* object);
 
 static const GOptionEntry MAIN_options[] = {{"debug", 'd', 0, G_OPTION_ARG_NONE, &main_has_debug, "Display debug statements on stdout", NULL}, {"version", (gchar) 0, 0, G_OPTION_ARG_NONE, &main_has_version, "Display version number", NULL}, {"disable-epg-scanner", (gchar) 0, 0, G_OPTION_ARG_NONE, &main_disable_epg_scanner, "Disable scanning for EPG data", NULL}, {NULL}};
 
@@ -68,8 +83,8 @@ static gboolean main_start_manager (void) {
 		guint request_name_result;
 		conn = dbus_g_bus_get (DBUS_BUS_SESSION, &inner_error);
 		if (inner_error != NULL) {
-			goto __catch4_g_error;
-			goto __finally4;
+			goto __catch5_g_error;
+			goto __finally5;
 		}
 		bus = dbus_g_proxy_new_for_name (conn, "org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus");
 		/* try to register service in session bus*/
@@ -77,63 +92,21 @@ static gboolean main_start_manager (void) {
 		if (inner_error != NULL) {
 			(conn == NULL) ? NULL : (conn = (dbus_g_connection_unref (conn), NULL));
 			(bus == NULL) ? NULL : (bus = (g_object_unref (bus), NULL));
-			goto __catch4_g_error;
-			goto __finally4;
+			goto __catch5_g_error;
+			goto __finally5;
 		}
 		if (request_name_result == DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER) {
-			g_debug ("Main.vala:35: Creating new Manager D-Bus service");
+			g_message ("Main.vala:54: Creating new Manager D-Bus service");
 			main_manager = dvb_manager_get_instance ();
 			_vala_dbus_register_object (dbus_g_connection_get_connection (conn), DVB_CONSTANTS_DBUS_MANAGER_PATH, (GObject*) main_manager);
 		} else {
 			gboolean _tmp0;
-			g_debug ("Main.vala:43: Manager D-Bus service is already running");
+			g_warning ("Main.vala:62: Manager D-Bus service is already running");
 			return (_tmp0 = FALSE, (conn == NULL) ? NULL : (conn = (dbus_g_connection_unref (conn), NULL)), (bus == NULL) ? NULL : (bus = (g_object_unref (bus), NULL)), _tmp0);
 		}
 		(conn == NULL) ? NULL : (conn = (dbus_g_connection_unref (conn), NULL));
 		(bus == NULL) ? NULL : (bus = (g_object_unref (bus), NULL));
 	}
-	goto __finally4;
-	__catch4_g_error:
-	{
-		GError * e;
-		e = inner_error;
-		inner_error = NULL;
-		{
-			gboolean _tmp1;
-			g_error ("Main.vala:48: Oops %s", e->message);
-			return (_tmp1 = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp1);
-		}
-	}
-	__finally4:
-	if (inner_error != NULL) {
-		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-		g_clear_error (&inner_error);
-		return FALSE;
-	}
-	return TRUE;
-}
-
-
-static gboolean main_start_recordings_store (guint32 minimum_id) {
-	GError * inner_error;
-	inner_error = NULL;
-	g_debug ("Main.vala:56: Creating new RecordingsStore D-Bus service");
-	{
-		DBusGConnection* conn;
-		DVBRecordingsStore* _tmp1;
-		DVBRecordingsStore* _tmp0;
-		conn = dbus_g_bus_get (DBUS_BUS_SESSION, &inner_error);
-		if (inner_error != NULL) {
-			goto __catch5_g_error;
-			goto __finally5;
-		}
-		_tmp1 = NULL;
-		_tmp0 = NULL;
-		main_recstore = (_tmp1 = (_tmp0 = dvb_recordings_store_get_instance (), (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (main_recstore == NULL) ? NULL : (main_recstore = (g_object_unref (main_recstore), NULL)), _tmp1);
-		dvb_recordings_store_update_last_id (main_recstore, minimum_id);
-		_vala_dbus_register_object (dbus_g_connection_get_connection (conn), DVB_CONSTANTS_DBUS_RECORDINGS_STORE_PATH, (GObject*) main_recstore);
-		(conn == NULL) ? NULL : (conn = (dbus_g_connection_unref (conn), NULL));
-	}
 	goto __finally5;
 	__catch5_g_error:
 	{
@@ -141,9 +114,9 @@ static gboolean main_start_recordings_store (guint32 minimum_id) {
 		e = inner_error;
 		inner_error = NULL;
 		{
-			gboolean _tmp2;
-			g_error ("Main.vala:68: Oops %s", e->message);
-			return (_tmp2 = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp2);
+			gboolean _tmp1;
+			g_error ("Main.vala:67: Oops %s", e->message);
+			return (_tmp1 = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp1);
 		}
 	}
 	__finally5:
@@ -156,10 +129,52 @@ static gboolean main_start_recordings_store (guint32 minimum_id) {
 }
 
 
+static gboolean main_start_recordings_store (guint32 minimum_id) {
+	GError * inner_error;
+	inner_error = NULL;
+	g_message ("Main.vala:75: Creating new RecordingsStore D-Bus service");
+	{
+		DBusGConnection* conn;
+		DVBRecordingsStore* _tmp1;
+		DVBRecordingsStore* _tmp0;
+		conn = dbus_g_bus_get (DBUS_BUS_SESSION, &inner_error);
+		if (inner_error != NULL) {
+			goto __catch6_g_error;
+			goto __finally6;
+		}
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		main_recstore = (_tmp1 = (_tmp0 = dvb_recordings_store_get_instance (), (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (main_recstore == NULL) ? NULL : (main_recstore = (g_object_unref (main_recstore), NULL)), _tmp1);
+		dvb_recordings_store_update_last_id (main_recstore, minimum_id);
+		_vala_dbus_register_object (dbus_g_connection_get_connection (conn), DVB_CONSTANTS_DBUS_RECORDINGS_STORE_PATH, (GObject*) main_recstore);
+		(conn == NULL) ? NULL : (conn = (dbus_g_connection_unref (conn), NULL));
+	}
+	goto __finally6;
+	__catch6_g_error:
+	{
+		GError * e;
+		e = inner_error;
+		inner_error = NULL;
+		{
+			gboolean _tmp2;
+			g_error ("Main.vala:87: Oops %s", e->message);
+			return (_tmp2 = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp2);
+		}
+	}
+	__finally6:
+	if (inner_error != NULL) {
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+		g_clear_error (&inner_error);
+		return FALSE;
+	}
+	return TRUE;
+}
+
+
 static void main_on_exit (gint signum) {
 	GstRTSPServer* _tmp0;
 	DVBRecordingsStore* _tmp1;
-	g_message ("Main.vala:76: Exiting");
+	g_message ("Main.vala:95: Exiting");
 	_tmp0 = NULL;
 	main_server = (_tmp0 = NULL, (main_server == NULL) ? NULL : (main_server = (g_object_unref (main_server), NULL)), _tmp0);
 	dvb_manager_shutdown ();
@@ -180,6 +195,11 @@ static void main_log_func (const char* log_domain, GLogLevelFlags log_levels, co
 }
 
 
+gboolean main_get_disable_epg_scanner (void) {
+	return main_disable_epg_scanner;
+}
+
+
 static void _main_on_exit_cutils_signal_signal_handler (gint signum) {
 	main_on_exit (signum);
 }
@@ -211,13 +231,13 @@ gint main_main (char** args, int args_length1) {
 		g_option_context_parse (context, &args_length1, &args, &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_OPTION_ERROR) {
-				goto __catch6_g_option_error;
+				goto __catch7_g_option_error;
 			}
-			goto __finally6;
+			goto __finally7;
 		}
 	}
-	goto __finally6;
-	__catch6_g_option_error:
+	goto __finally7;
+	__catch7_g_option_error:
 	{
 		GError * e;
 		e = inner_error;
@@ -229,7 +249,7 @@ gint main_main (char** args, int args_length1) {
 			return (_tmp0 = 1, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), _tmp0);
 		}
 	}
-	__finally6:
+	__finally7:
 	if (inner_error != NULL) {
 		(context == NULL) ? NULL : (context = (g_option_context_free (context), NULL));
 		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
@@ -255,6 +275,7 @@ gint main_main (char** args, int args_length1) {
 	max_id = (guint32) 0;
 	timers_store = dvb_factory_get_timers_store ();
 	config_store = dvb_factory_get_config_store ();
+	g_message ("Main.vala:158: Restoring device groups");
 	device_groups = dvb_config_store_get_all_device_groups (config_store);
 	{
 		GeeIterator* _device_group_it;
@@ -266,12 +287,10 @@ gint main_main (char** args, int args_length1) {
 				DVBRecorder* _tmp4;
 				DVBRecorder* rec;
 				GeeList* timers;
-				if (!main_disable_epg_scanner) {
-					dvb_epg_scanner_start (dvb_device_group_get_epgscanner (device_group));
-				}
 				_tmp4 = NULL;
 				rec = (_tmp4 = dvb_device_group_get_recorder (device_group), (_tmp4 == NULL) ? NULL : g_object_ref (_tmp4));
 				/* Restore timers*/
+				g_message ("Main.vala:166: Restoring timers of device group %u", dvb_device_group_get_Id (device_group));
 				timers = dvb_timers_store_get_all_timers_of_device_group (timers_store, device_group);
 				{
 					GeeIterator* _t_it;
@@ -302,6 +321,7 @@ gint main_main (char** args, int args_length1) {
 		gint _tmp5;
 		return (_tmp5 = -1, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), (device_groups == NULL) ? NULL : (device_groups = (g_object_unref (device_groups), NULL)), _tmp5);
 	}
+	g_message ("Main.vala:181: Starting RTSP server");
 	_tmp6 = NULL;
 	main_server = (_tmp6 = gst_rtsp_server_new (), (main_server == NULL) ? NULL : (main_server = (g_object_unref (main_server), NULL)), _tmp6);
 	_tmp7 = NULL;
@@ -349,5 +369,13 @@ static void _vala_dbus_register_object (DBusConnection* connection, const char*
 }
 
 
+static void _vala_dbus_unregister_object (gpointer connection, GObject* object) {
+	char* path;
+	path = g_object_steal_data ((GObject*) object, "dbus_object_path");
+	dbus_connection_unregister_object_path (connection, path);
+	g_free (path);
+}
+
+
 
 
