@@ -1,13 +1,28 @@
+/*
+ * Copyright (C) 2008,2009 Sebastian Pölsterl
+ *
+ * This file is part of GNOME DVB Daemon.
+ *
+ * GNOME DVB Daemon is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * GNOME DVB Daemon is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef __SRC_RECORDER_H__
 #define __SRC_RECORDER_H__
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/iterable.h>
-#include <gee/map.h>
-#include <gee/set.h>
-#include <gee/iterator.h>
+#include <gee.h>
 #include <gio/gio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -19,6 +34,7 @@
 #include "src/Recording.h"
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib.h>
+#include <dbus/dbus-glib-lowlevel.h>
 
 G_BEGIN_DECLS
 
@@ -83,6 +99,7 @@ DVBRecorder* dvb_recorder_construct (GType object_type, DVBDeviceGroup* dev);
 DVBRecorder* dvb_recorder_new (DVBDeviceGroup* dev);
 guint32 dvb_recorder_add_timer (DVBRecorder* self, DVBTimer* new_timer);
 void dvb_recorder_stop (DVBRecorder* self);
+DVBTimer* dvb_recorder_create_timer (DVBRecorder* self, guint channel, gint start_year, gint start_month, gint start_day, gint start_hour, gint start_minute, guint duration);
 void dvb_recorder_start_recording (DVBRecorder* self, DVBTimer* timer);
 void dvb_recorder_stop_recording (DVBRecorder* self, DVBTimer* timer);
 DVBDeviceGroup* dvb_recorder_get_DeviceGroup (DVBRecorder* self);
