@@ -1,13 +1,30 @@
+/*
+ * Copyright (C) 2008,2009 Sebastian Pölsterl
+ *
+ * This file is part of GNOME DVB Daemon.
+ *
+ * GNOME DVB Daemon is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * GNOME DVB Daemon is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include <src/SqliteConfigTimersStore.h>
 #include <sqlite3.h>
-#include <gee/arraylist.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
 #include <gio/gio.h>
-#include <gee/iterator.h>
 #include "src/ChannelList.h"
+#include "src/Main.h"
+#include "src/Channel.h"
 #include "src/Utils.h"
 
 
@@ -46,13 +63,13 @@ enum  {
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_INSERT_TIMER "INSERT INTO timers VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)"
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_CONTAINS_TIMER "SELECT COUNT(*) FROM timers WHERE timer_id=?"
 static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBConfigStore* base);
-static void dvb_sqlite_config_timers_store_real_add_device_group (DVBConfigStore* base, DVBDeviceGroup* dev_group);
-static void dvb_sqlite_config_timers_store_real_remove_device_group (DVBConfigStore* base, DVBDeviceGroup* devgroup);
-static void dvb_sqlite_config_timers_store_real_add_device_to_group (DVBConfigStore* base, DVBDevice* dev, DVBDeviceGroup* devgroup);
-static void dvb_sqlite_config_timers_store_real_remove_device_from_group (DVBConfigStore* base, DVBDevice* dev, DVBDeviceGroup* devgroup);
+static gboolean dvb_sqlite_config_timers_store_real_add_device_group (DVBConfigStore* base, DVBDeviceGroup* dev_group);
+static gboolean dvb_sqlite_config_timers_store_real_remove_device_group (DVBConfigStore* base, DVBDeviceGroup* devgroup);
+static gboolean dvb_sqlite_config_timers_store_real_add_device_to_group (DVBConfigStore* base, DVBDevice* dev, DVBDeviceGroup* devgroup);
+static gboolean dvb_sqlite_config_timers_store_real_remove_device_from_group (DVBConfigStore* base, DVBDevice* dev, DVBDeviceGroup* devgroup);
 static GeeList* dvb_sqlite_config_timers_store_real_get_all_timers_of_device_group (DVBTimersStore* base, DVBDeviceGroup* dev);
-static void dvb_sqlite_config_timers_store_real_add_timer_to_device_group (DVBTimersStore* base, DVBTimer* timer, DVBDeviceGroup* dev);
-static void dvb_sqlite_config_timers_store_real_remove_timer_from_device_group (DVBTimersStore* base, guint timer_id, DVBDeviceGroup* dev);
+static gboolean dvb_sqlite_config_timers_store_real_add_timer_to_device_group (DVBTimersStore* base, DVBTimer* timer, DVBDeviceGroup* dev);
+static gboolean dvb_sqlite_config_timers_store_real_remove_timer_from_device_group (DVBTimersStore* base, guint timer_id, DVBDeviceGroup* dev);
 static void dvb_sqlite_config_timers_store_print_last_error (DVBSqliteConfigTimersStore* self);
 static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void);
 static GObject * dvb_sqlite_config_timers_store_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
@@ -115,7 +132,7 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 		}
 		/* No devices for this group*/
 		if (gee_collection_get_size ((GeeCollection*) devs) == 0) {
-			g_debug ("SqliteConfigTimersStore.vala:143: Group %d has no devices", group_id);
+			g_debug ("SqliteConfigTimersStore.vala:162: Group %d has no devices", group_id);
 			(devs == NULL) ? NULL : (devs = (g_object_unref (devs), NULL));
 			continue;
 		}
@@ -123,24 +140,24 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 		group_type = sqlite3_column_int (statement, 1);
 		type = 0;
 		switch (group_type) {
-			case 0:
+			case 1:
 			{
 				type = DVB_ADAPTER_TYPE_DVB_T;
 				break;
 			}
-			case 1:
+			case 2:
 			{
 				type = DVB_ADAPTER_TYPE_DVB_S;
 				break;
 			}
-			case 2:
+			case 3:
 			{
 				type = DVB_ADAPTER_TYPE_DVB_C;
 				break;
 			}
 			default:
 			{
-				g_debug ("SqliteConfigTimersStore.vala:155: Group %d has unknown type %d", group_id, group_type);
+				g_debug ("SqliteConfigTimersStore.vala:174: Group %d has unknown type %d", group_id, group_type);
 				continue;
 			}
 		}
@@ -150,22 +167,22 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 		{
 			DVBChannelList* _tmp5;
 			DVBChannelList* _tmp6;
-			_tmp5 = dvb_channel_list_restore_from_file (channels_file, type, &inner_error);
+			_tmp5 = dvb_channel_list_restore_from_file (channels_file, type, (guint) group_id, &inner_error);
 			if (inner_error != NULL) {
-				goto __catch23_g_error;
-				goto __finally23;
+				goto __catch33_g_error;
+				goto __finally33;
 			}
 			_tmp6 = NULL;
 			channels = (_tmp6 = _tmp5, (channels == NULL) ? NULL : (channels = (g_object_unref (channels), NULL)), _tmp6);
 		}
-		goto __finally23;
-		__catch23_g_error:
+		goto __finally33;
+		__catch33_g_error:
 		{
 			GError * e;
 			e = inner_error;
 			inner_error = NULL;
 			{
-				g_warning ("SqliteConfigTimersStore.vala:168: Could not read channels: %s", e->message);
+				g_warning ("SqliteConfigTimersStore.vala:187: Could not read channels: %s", e->message);
 				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 				(devs == NULL) ? NULL : (devs = (g_object_unref (devs), NULL));
 				(channels_file == NULL) ? NULL : (channels_file = (g_object_unref (channels_file), NULL));
@@ -173,7 +190,7 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 				continue;
 			}
 		}
-		__finally23:
+		__finally33:
 		if (inner_error != NULL) {
 			(devs == NULL) ? NULL : (devs = (g_object_unref (devs), NULL));
 			(channels_file == NULL) ? NULL : (channels_file = (g_object_unref (channels_file), NULL));
@@ -190,7 +207,7 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 		dvb_device_set_Channels (ref_dev, channels);
 		dvb_device_set_RecordingsDirectory (ref_dev, rec_dir);
 		/* Create device group*/
-		group = dvb_device_group_new ((guint) group_id, ref_dev);
+		group = dvb_device_group_new ((guint) group_id, ref_dev, !main_get_disable_epg_scanner ());
 		dvb_device_group_set_Name (group, sqlite3_column_text (statement, 4));
 		{
 			gint i;
@@ -215,63 +232,62 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 }
 
 
-static void dvb_sqlite_config_timers_store_real_add_device_group (DVBConfigStore* base, DVBDeviceGroup* dev_group) {
+static gboolean dvb_sqlite_config_timers_store_real_add_device_group (DVBConfigStore* base, DVBDeviceGroup* dev_group) {
 	DVBSqliteConfigTimersStore * self;
 	char* channels;
 	char* recdir;
-	gboolean _tmp0;
 	gboolean _tmp1;
 	gboolean _tmp2;
 	gboolean _tmp3;
+	gboolean _tmp4;
+	gboolean _tmp10;
 	self = (DVBSqliteConfigTimersStore*) base;
-	g_return_if_fail (dev_group != NULL);
+	g_return_val_if_fail (dev_group != NULL, FALSE);
 	if (dvb_sqlite_config_timers_store_contains_group (self, dvb_device_group_get_Id (dev_group))) {
-		return;
+		return FALSE;
 	}
 	channels = g_file_get_path (dvb_channel_list_get_channels_file (dvb_device_group_get_Channels (dev_group)));
 	recdir = g_file_get_path (dvb_device_group_get_RecordingsDirectory (dev_group));
 	sqlite3_reset (self->priv->insert_group_statement);
-	_tmp0 = FALSE;
 	_tmp1 = FALSE;
 	_tmp2 = FALSE;
 	_tmp3 = FALSE;
+	_tmp4 = FALSE;
 	if (sqlite3_bind_int (self->priv->insert_group_statement, 1, (gint) dvb_device_group_get_Id (dev_group)) != SQLITE_OK) {
+		_tmp4 = TRUE;
+	} else {
+		_tmp4 = sqlite3_bind_int (self->priv->insert_group_statement, 2, (gint) dvb_device_group_get_Type (dev_group)) != SQLITE_OK;
+	}
+	if (_tmp4) {
 		_tmp3 = TRUE;
 	} else {
-		_tmp3 = sqlite3_bind_int (self->priv->insert_group_statement, 2, (gint) dvb_device_group_get_Type (dev_group)) != SQLITE_OK;
+		const char* _tmp5;
+		_tmp5 = NULL;
+		_tmp3 = sqlite3_bind_text (self->priv->insert_group_statement, 3, (_tmp5 = channels, (_tmp5 == NULL) ? NULL : g_strdup (_tmp5)), -1, g_free) != SQLITE_OK;
 	}
 	if (_tmp3) {
 		_tmp2 = TRUE;
 	} else {
-		const char* _tmp4;
-		_tmp4 = NULL;
-		_tmp2 = sqlite3_bind_text (self->priv->insert_group_statement, 3, (_tmp4 = channels, (_tmp4 == NULL) ? NULL : g_strdup (_tmp4)), -1, g_free) != SQLITE_OK;
+		const char* _tmp6;
+		_tmp6 = NULL;
+		_tmp2 = sqlite3_bind_text (self->priv->insert_group_statement, 4, (_tmp6 = recdir, (_tmp6 == NULL) ? NULL : g_strdup (_tmp6)), -1, g_free) != SQLITE_OK;
 	}
 	if (_tmp2) {
 		_tmp1 = TRUE;
 	} else {
-		const char* _tmp5;
-		_tmp5 = NULL;
-		_tmp1 = sqlite3_bind_text (self->priv->insert_group_statement, 4, (_tmp5 = recdir, (_tmp5 == NULL) ? NULL : g_strdup (_tmp5)), -1, g_free) != SQLITE_OK;
+		const char* _tmp7;
+		_tmp7 = NULL;
+		_tmp1 = sqlite3_bind_text (self->priv->insert_group_statement, 5, (_tmp7 = dvb_device_group_get_Name (dev_group), (_tmp7 == NULL) ? NULL : g_strdup (_tmp7)), -1, g_free) != SQLITE_OK;
 	}
 	if (_tmp1) {
-		_tmp0 = TRUE;
-	} else {
-		const char* _tmp6;
-		_tmp6 = NULL;
-		_tmp0 = sqlite3_bind_text (self->priv->insert_group_statement, 5, (_tmp6 = dvb_device_group_get_Name (dev_group), (_tmp6 == NULL) ? NULL : g_strdup (_tmp6)), -1, g_free) != SQLITE_OK;
-	}
-	if (_tmp0) {
+		gboolean _tmp8;
 		dvb_sqlite_config_timers_store_print_last_error (self);
-		channels = (g_free (channels), NULL);
-		recdir = (g_free (recdir), NULL);
-		return;
+		return (_tmp8 = FALSE, channels = (g_free (channels), NULL), recdir = (g_free (recdir), NULL), _tmp8);
 	}
 	if (sqlite3_step (self->priv->insert_group_statement) != SQLITE_DONE) {
+		gboolean _tmp9;
 		dvb_sqlite_config_timers_store_print_last_error (self);
-		channels = (g_free (channels), NULL);
-		recdir = (g_free (recdir), NULL);
-		return;
+		return (_tmp9 = FALSE, channels = (g_free (channels), NULL), recdir = (g_free (recdir), NULL), _tmp9);
 	}
 	{
 		GeeIterator* _dev_it;
@@ -284,23 +300,24 @@ static void dvb_sqlite_config_timers_store_real_add_device_group (DVBConfigStore
 		}
 		(_dev_it == NULL) ? NULL : (_dev_it = (g_object_unref (_dev_it), NULL));
 	}
-	channels = (g_free (channels), NULL);
-	recdir = (g_free (recdir), NULL);
+	return (_tmp10 = TRUE, channels = (g_free (channels), NULL), recdir = (g_free (recdir), NULL), _tmp10);
 }
 
 
-static void dvb_sqlite_config_timers_store_real_remove_device_group (DVBConfigStore* base, DVBDeviceGroup* devgroup) {
+static gboolean dvb_sqlite_config_timers_store_real_remove_device_group (DVBConfigStore* base, DVBDeviceGroup* devgroup) {
 	DVBSqliteConfigTimersStore * self;
 	self = (DVBSqliteConfigTimersStore*) base;
-	g_return_if_fail (devgroup != NULL);
+	g_return_val_if_fail (devgroup != NULL, FALSE);
 	sqlite3_reset (self->priv->delete_group_statement);
 	if (sqlite3_bind_int (self->priv->delete_group_statement, 1, (gint) dvb_device_group_get_Id (devgroup)) != SQLITE_OK) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
-		return;
+		return FALSE;
 	}
 	if (sqlite3_step (self->priv->delete_group_statement) != SQLITE_DONE) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
+		return FALSE;
 	}
+	return TRUE;
 }
 
 
@@ -316,17 +333,17 @@ gboolean dvb_sqlite_config_timers_store_contains_group (DVBSqliteConfigTimersSto
 	while (sqlite3_step (self->priv->contains_group_statement) == SQLITE_ROW) {
 		c = sqlite3_column_int (self->priv->contains_group_statement, 0);
 	}
-	return (c > 0);
+	return c > 0;
 }
 
 
-static void dvb_sqlite_config_timers_store_real_add_device_to_group (DVBConfigStore* base, DVBDevice* dev, DVBDeviceGroup* devgroup) {
+static gboolean dvb_sqlite_config_timers_store_real_add_device_to_group (DVBConfigStore* base, DVBDevice* dev, DVBDeviceGroup* devgroup) {
 	DVBSqliteConfigTimersStore * self;
 	gboolean _tmp0;
 	gboolean _tmp1;
 	self = (DVBSqliteConfigTimersStore*) base;
-	g_return_if_fail (dev != NULL);
-	g_return_if_fail (devgroup != NULL);
+	g_return_val_if_fail (dev != NULL, FALSE);
+	g_return_val_if_fail (devgroup != NULL, FALSE);
 	sqlite3_reset (self->priv->insert_device_statement);
 	_tmp0 = FALSE;
 	_tmp1 = FALSE;
@@ -342,20 +359,22 @@ static void dvb_sqlite_config_timers_store_real_add_device_to_group (DVBConfigSt
 	}
 	if (_tmp0) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
-		return;
+		return FALSE;
 	}
 	if (sqlite3_step (self->priv->insert_device_statement) != SQLITE_DONE) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
+		return FALSE;
 	}
+	return TRUE;
 }
 
 
-static void dvb_sqlite_config_timers_store_real_remove_device_from_group (DVBConfigStore* base, DVBDevice* dev, DVBDeviceGroup* devgroup) {
+static gboolean dvb_sqlite_config_timers_store_real_remove_device_from_group (DVBConfigStore* base, DVBDevice* dev, DVBDeviceGroup* devgroup) {
 	DVBSqliteConfigTimersStore * self;
 	gboolean _tmp0;
 	self = (DVBSqliteConfigTimersStore*) base;
-	g_return_if_fail (dev != NULL);
-	g_return_if_fail (devgroup != NULL);
+	g_return_val_if_fail (dev != NULL, FALSE);
+	g_return_val_if_fail (devgroup != NULL, FALSE);
 	sqlite3_reset (self->priv->delete_device_statement);
 	_tmp0 = FALSE;
 	if (sqlite3_bind_int (self->priv->delete_device_statement, 1, (gint) dvb_device_get_Adapter (dev)) != SQLITE_OK) {
@@ -365,11 +384,13 @@ static void dvb_sqlite_config_timers_store_real_remove_device_from_group (DVBCon
 	}
 	if (_tmp0) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
-		return;
+		return FALSE;
 	}
 	if (sqlite3_step (self->priv->delete_device_statement) != SQLITE_DONE) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
+		return FALSE;
 	}
+	return TRUE;
 }
 
 
@@ -393,6 +414,7 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_timers_of_device_gro
 		gint day;
 		gint hour;
 		gint minute;
+		DVBChannel* channel;
 		DVBTimer* _tmp1;
 		tid = 0U;
 		sid = 0U;
@@ -410,17 +432,18 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_timers_of_device_gro
 		hour = sqlite3_column_int (self->priv->select_timers_statement, 6);
 		minute = sqlite3_column_int (self->priv->select_timers_statement, 7);
 		duration = (guint) sqlite3_column_int (self->priv->select_timers_statement, 8);
+		channel = dvb_channel_list_get_channel (dvb_device_group_get_Channels (dev), sid);
 		_tmp1 = NULL;
-		gee_collection_add ((GeeCollection*) timers, _tmp1 = dvb_timer_new ((guint32) tid, sid, year, month, day, hour, minute, duration, NULL));
+		gee_collection_add ((GeeCollection*) timers, _tmp1 = dvb_timer_new ((guint32) tid, channel, year, month, day, hour, minute, duration, NULL));
 		(_tmp1 == NULL) ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL));
+		(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
 	}
 	return timers;
 }
 
 
-static void dvb_sqlite_config_timers_store_real_add_timer_to_device_group (DVBTimersStore* base, DVBTimer* timer, DVBDeviceGroup* dev) {
+static gboolean dvb_sqlite_config_timers_store_real_add_timer_to_device_group (DVBTimersStore* base, DVBTimer* timer, DVBDeviceGroup* dev) {
 	DVBSqliteConfigTimersStore * self;
-	gboolean _tmp0;
 	gboolean _tmp1;
 	gboolean _tmp2;
 	gboolean _tmp3;
@@ -428,14 +451,14 @@ static void dvb_sqlite_config_timers_store_real_add_timer_to_device_group (DVBTi
 	gboolean _tmp5;
 	gboolean _tmp6;
 	gboolean _tmp7;
+	gboolean _tmp8;
 	self = (DVBSqliteConfigTimersStore*) base;
-	g_return_if_fail (timer != NULL);
-	g_return_if_fail (dev != NULL);
+	g_return_val_if_fail (timer != NULL, FALSE);
+	g_return_val_if_fail (dev != NULL, FALSE);
 	if (dvb_sqlite_config_timers_store_contains_timer (self, (guint) dvb_timer_get_Id (timer))) {
-		return;
+		return FALSE;
 	}
 	sqlite3_reset (self->priv->insert_timer_statement);
-	_tmp0 = FALSE;
 	_tmp1 = FALSE;
 	_tmp2 = FALSE;
 	_tmp3 = FALSE;
@@ -443,68 +466,73 @@ static void dvb_sqlite_config_timers_store_real_add_timer_to_device_group (DVBTi
 	_tmp5 = FALSE;
 	_tmp6 = FALSE;
 	_tmp7 = FALSE;
+	_tmp8 = FALSE;
 	if (sqlite3_bind_int (self->priv->insert_timer_statement, 1, (gint) dvb_timer_get_Id (timer)) != SQLITE_OK) {
+		_tmp8 = TRUE;
+	} else {
+		_tmp8 = sqlite3_bind_int (self->priv->insert_timer_statement, 2, (gint) dvb_device_group_get_Id (dev)) != SQLITE_OK;
+	}
+	if (_tmp8) {
 		_tmp7 = TRUE;
 	} else {
-		_tmp7 = sqlite3_bind_int (self->priv->insert_timer_statement, 2, (gint) dvb_device_group_get_Id (dev)) != SQLITE_OK;
+		_tmp7 = sqlite3_bind_int (self->priv->insert_timer_statement, 3, (gint) dvb_channel_get_Sid (dvb_timer_get_Channel (timer))) != SQLITE_OK;
 	}
 	if (_tmp7) {
 		_tmp6 = TRUE;
 	} else {
-		_tmp6 = sqlite3_bind_int (self->priv->insert_timer_statement, 3, (gint) dvb_timer_get_ChannelSid (timer)) != SQLITE_OK;
+		_tmp6 = sqlite3_bind_int (self->priv->insert_timer_statement, 4, (gint) dvb_timer_get_Year (timer)) != SQLITE_OK;
 	}
 	if (_tmp6) {
 		_tmp5 = TRUE;
 	} else {
-		_tmp5 = sqlite3_bind_int (self->priv->insert_timer_statement, 4, (gint) dvb_timer_get_Year (timer)) != SQLITE_OK;
+		_tmp5 = sqlite3_bind_int (self->priv->insert_timer_statement, 5, (gint) dvb_timer_get_Month (timer)) != SQLITE_OK;
 	}
 	if (_tmp5) {
 		_tmp4 = TRUE;
 	} else {
-		_tmp4 = sqlite3_bind_int (self->priv->insert_timer_statement, 5, (gint) dvb_timer_get_Month (timer)) != SQLITE_OK;
+		_tmp4 = sqlite3_bind_int (self->priv->insert_timer_statement, 6, (gint) dvb_timer_get_Day (timer)) != SQLITE_OK;
 	}
 	if (_tmp4) {
 		_tmp3 = TRUE;
 	} else {
-		_tmp3 = sqlite3_bind_int (self->priv->insert_timer_statement, 6, (gint) dvb_timer_get_Day (timer)) != SQLITE_OK;
+		_tmp3 = sqlite3_bind_int (self->priv->insert_timer_statement, 7, (gint) dvb_timer_get_Hour (timer)) != SQLITE_OK;
 	}
 	if (_tmp3) {
 		_tmp2 = TRUE;
 	} else {
-		_tmp2 = sqlite3_bind_int (self->priv->insert_timer_statement, 7, (gint) dvb_timer_get_Hour (timer)) != SQLITE_OK;
+		_tmp2 = sqlite3_bind_int (self->priv->insert_timer_statement, 8, (gint) dvb_timer_get_Minute (timer)) != SQLITE_OK;
 	}
 	if (_tmp2) {
 		_tmp1 = TRUE;
 	} else {
-		_tmp1 = sqlite3_bind_int (self->priv->insert_timer_statement, 8, (gint) dvb_timer_get_Minute (timer)) != SQLITE_OK;
+		_tmp1 = sqlite3_bind_int (self->priv->insert_timer_statement, 9, (gint) dvb_timer_get_Duration (timer)) != SQLITE_OK;
 	}
 	if (_tmp1) {
-		_tmp0 = TRUE;
-	} else {
-		_tmp0 = sqlite3_bind_int (self->priv->insert_timer_statement, 9, (gint) dvb_timer_get_Duration (timer)) != SQLITE_OK;
-	}
-	if (_tmp0) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
-		return;
+		return FALSE;
 	}
 	if (sqlite3_step (self->priv->insert_timer_statement) != SQLITE_DONE) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
+		return FALSE;
 	}
+	return TRUE;
 }
 
 
-static void dvb_sqlite_config_timers_store_real_remove_timer_from_device_group (DVBTimersStore* base, guint timer_id, DVBDeviceGroup* dev) {
+static gboolean dvb_sqlite_config_timers_store_real_remove_timer_from_device_group (DVBTimersStore* base, guint timer_id, DVBDeviceGroup* dev) {
 	DVBSqliteConfigTimersStore * self;
 	self = (DVBSqliteConfigTimersStore*) base;
-	g_return_if_fail (dev != NULL);
+	g_return_val_if_fail (dev != NULL, FALSE);
 	sqlite3_reset (self->priv->delete_timer_statement);
 	if (sqlite3_bind_int (self->priv->delete_timer_statement, 1, (gint) timer_id) != SQLITE_OK) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
-		return;
+		return FALSE;
 	}
 	if (sqlite3_step (self->priv->delete_timer_statement) != SQLITE_DONE) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
+		return FALSE;
 	}
+	return TRUE;
 }
 
 
@@ -520,13 +548,13 @@ gboolean dvb_sqlite_config_timers_store_contains_timer (DVBSqliteConfigTimersSto
 	while (sqlite3_step (self->priv->contains_timer_statement) == SQLITE_ROW) {
 		c = sqlite3_column_int (self->priv->contains_timer_statement, 0);
 	}
-	return (c > 0);
+	return c > 0;
 }
 
 
 static void dvb_sqlite_config_timers_store_print_last_error (DVBSqliteConfigTimersStore* self) {
 	g_return_if_fail (self != NULL);
-	g_critical ("SqliteConfigTimersStore.vala:353: SQLite error: %d, %s", sqlite3_errcode (self->priv->db), sqlite3_errmsg (self->priv->db));
+	g_critical ("SqliteConfigTimersStore.vala:391: SQLite error: %d, %s", sqlite3_errcode (self->priv->db), sqlite3_errmsg (self->priv->db));
 }
 
 
@@ -550,24 +578,24 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 		{
 			dvb_utils_mkdirs (config_cache, &inner_error);
 			if (inner_error != NULL) {
-				goto __catch24_g_error;
-				goto __finally24;
+				goto __catch34_g_error;
+				goto __finally34;
 			}
 		}
-		goto __finally24;
-		__catch24_g_error:
+		goto __finally34;
+		__catch34_g_error:
 		{
 			GError * e;
 			e = inner_error;
 			inner_error = NULL;
 			{
 				sqlite3* _tmp0;
-				g_critical ("SqliteConfigTimersStore.vala:367: Could not create directory: %s", e->message);
+				g_critical ("SqliteConfigTimersStore.vala:405: Could not create directory: %s", e->message);
 				_tmp0 = NULL;
 				return (_tmp0 = NULL, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), (config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL)), (config_cache == NULL) ? NULL : (config_cache = (g_object_unref (config_cache), NULL)), (dbfile == NULL) ? NULL : (dbfile = (g_object_unref (dbfile), NULL)), _tmp0);
 			}
 		}
-		__finally24:
+		__finally34:
 		if (inner_error != NULL) {
 			(config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL));
 			(config_cache == NULL) ? NULL : (config_cache = (g_object_unref (config_cache), NULL));
@@ -577,7 +605,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 			return NULL;
 		}
 	}
-	create_tables = (!g_file_query_exists (dbfile, NULL));
+	create_tables = !g_file_query_exists (dbfile, NULL);
 	db = NULL;
 	_tmp4 = NULL;
 	_tmp2 = NULL;
@@ -604,7 +632,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 		val = (_tmp6 = sqlite3_exec (db, DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_DEVICE_GROUPS, NULL, NULL, &_tmp5), errormsg = (_tmp7 = _tmp5, errormsg = (g_free (errormsg), NULL), _tmp7), _tmp6);
 		if (val != SQLITE_OK) {
 			sqlite3* _tmp8;
-			g_critical ("SqliteConfigTimersStore.vala:380: SQLite error: %s", errormsg);
+			g_critical ("SqliteConfigTimersStore.vala:418: SQLite error: %s", errormsg);
 			_tmp8 = NULL;
 			return (_tmp8 = NULL, errormsg = (g_free (errormsg), NULL), (config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL)), (config_cache == NULL) ? NULL : (config_cache = (g_object_unref (config_cache), NULL)), (dbfile == NULL) ? NULL : (dbfile = (g_object_unref (dbfile), NULL)), (db == NULL) ? NULL : (db = (sqlite3_close (db), NULL)), _tmp8);
 		}
@@ -613,7 +641,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 		val = (_tmp10 = sqlite3_exec (db, DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_DEVICES, NULL, NULL, &_tmp9), errormsg = (_tmp11 = _tmp9, errormsg = (g_free (errormsg), NULL), _tmp11), _tmp10);
 		if (val != SQLITE_OK) {
 			sqlite3* _tmp12;
-			g_critical ("SqliteConfigTimersStore.vala:386: SQLite error: %s", errormsg);
+			g_critical ("SqliteConfigTimersStore.vala:424: SQLite error: %s", errormsg);
 			_tmp12 = NULL;
 			return (_tmp12 = NULL, errormsg = (g_free (errormsg), NULL), (config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL)), (config_cache == NULL) ? NULL : (config_cache = (g_object_unref (config_cache), NULL)), (dbfile == NULL) ? NULL : (dbfile = (g_object_unref (dbfile), NULL)), (db == NULL) ? NULL : (db = (sqlite3_close (db), NULL)), _tmp12);
 		}
@@ -622,7 +650,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 		val = (_tmp14 = sqlite3_exec (db, DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_TIMERS, NULL, NULL, &_tmp13), errormsg = (_tmp15 = _tmp13, errormsg = (g_free (errormsg), NULL), _tmp15), _tmp14);
 		if (val != SQLITE_OK) {
 			sqlite3* _tmp16;
-			g_critical ("SqliteConfigTimersStore.vala:392: SQLite error: %s", errormsg);
+			g_critical ("SqliteConfigTimersStore.vala:430: SQLite error: %s", errormsg);
 			_tmp16 = NULL;
 			return (_tmp16 = NULL, errormsg = (g_free (errormsg), NULL), (config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL)), (config_cache == NULL) ? NULL : (config_cache = (g_object_unref (config_cache), NULL)), (dbfile == NULL) ? NULL : (dbfile = (g_object_unref (dbfile), NULL)), (db == NULL) ? NULL : (db = (sqlite3_close (db), NULL)), _tmp16);
 		}
